@@ -4,11 +4,13 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-11'; # DATE
+our $DATE = '2024-01-01'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20231211.0'; # VERSION
+our $VERSION = '20240101.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
+    'JGNI' => '',
+    'MIKKOI' => '',
     'PERLANCAR' => '',
 );
 
@@ -28,18 +30,20 @@ Acme::CPANAuthors::CPAN::Streaks::DailyNewDistributions::Current - Authors with
 
 =head1 VERSION
 
-This document describes version 20231211.0 of Acme::CPANAuthors::CPAN::Streaks::DailyNewDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2023-12-11.
+This document describes version 20240101.0 of Acme::CPANAuthors::CPAN::Streaks::DailyNewDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-01-01.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2023-12-11, produced by L<cpan-streaks>):
+Current standings (as of 2024-01-01, produced by L<cpan-streaks>):
 
   +-----------+-----+------------+-------------+
   | author    | len | start_date | status      |
   +-----------+-----+------------+-------------+
-  | PERLANCAR |   1 | 2023-12-10 | might-break |
+  | JGNI      |   2 | 2023-12-31 | ongoing     |
+  | MIKKOI    |   1 | 2023-12-31 | might-break |
+  | PERLANCAR |   1 | 2023-12-31 | might-break |
   +-----------+-----+------------+-------------+
 
 =head1 HOMEPAGE
@@ -81,7 +85,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
