@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-11'; # DATE
+our $DATE = '2024-01-01'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20231211.0'; # VERSION
+our $VERSION = '20240101.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
     'PERLANCAR' => '',
@@ -156,18 +156,18 @@ Acme::CPANAuthors::CPAN::Streaks::MonthlyDistributions::AllTime - Authors with a
 
 =head1 VERSION
 
-This document describes version 20231211.0 of Acme::CPANAuthors::CPAN::Streaks::MonthlyDistributions::AllTime (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2023-12-11.
+This document describes version 20240101.0 of Acme::CPANAuthors::CPAN::Streaks::MonthlyDistributions::AllTime (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-01-01.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2023-12-11, produced by L<cpan-streaks>, only streaks with length of at least 6 are included):
+Current standings (as of 2024-01-01, produced by L<cpan-streaks>, only streaks with length of at least 6 are included):
 
   +-----------+-----+------------+----------+-------------+
   | author    | len | start_date | end_date | status      |
   +-----------+-----+------------+----------+-------------+
-  | PERLANCAR | 113 | 2014-08    |          | ongoing     |
+  | PERLANCAR | 113 | 2014-08    |          | might-break |
   | MGV       |  53 | 2014-01    | 2018-05  | broken      |
   | KENTNL    |  46 | 2013-01    | 2016-10  | broken      |
   | ETHER     |  36 | 2013-01    | 2015-12  | broken      |
@@ -218,7 +218,7 @@ Current standings (as of 2023-12-11, produced by L<cpan-streaks>, only streaks w
   | MANWAR    |  10 | 2015-08    | 2016-05  | broken      |
   | ETJ       |  10 | 2020-05    | 2021-02  | broken      |
   | PEVANS    |  10 | 2021-03    | 2021-12  | broken      |
-  | SKIM      |  10 | 2023-03    |          | ongoing     |
+  | SKIM      |  10 | 2023-03    |          | might-break |
   | MIYAGAWA  |   9 | 2001-05    | 2002-01  | broken      |
   | AUTRIJUS  |   9 | 2003-07    | 2004-03  | broken      |
   | STEVAN    |   9 | 2004-03    | 2004-11  | broken      |
@@ -375,7 +375,7 @@ Current standings (as of 2023-12-11, produced by L<cpan-streaks>, only streaks w
   | PRBRENAN  |   6 | 2021-01    | 2021-06  | broken      |
   | UTASHIRO  |   6 | 2022-04    | 2022-09  | broken      |
   | BRTASTIC  |   6 | 2022-08    | 2023-01  | broken      |
-  | TIMLEGGE  |   6 | 2023-06    |          | might-break |
+  | TIMLEGGE  |   6 | 2023-06    | 2023-11  | broken      |
   +-----------+-----+------------+----------+-------------+
 
 =head1 HOMEPAGE
@@ -417,7 +417,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
