@@ -4,22 +4,27 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-11'; # DATE
+our $DATE = '2024-01-01'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20231211.0'; # VERSION
+our $VERSION = '20240101.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
     'PERLANCAR' => '',
-    'SKIM' => '',
+    'INGY' => '',
     'KIMOTO' => '',
-    'AAHAZRED' => '',
-    'ABALAMA' => '',
-    'CGPAN' => '',
-    'DJERIUS' => '',
-    'ETHER' => '',
-    'GBROWN' => '',
-    'JJATRIA' => '',
-    'TEODESIAN' => '',
+    'AJNN' => '',
+    'BOOK' => '',
+    'GENE' => '',
+    'JKSTILL' => '',
+    'JMATES' => '',
+    'JV' => '',
+    'MATHIAS' => '',
+    'MRDVT' => '',
+    'SKIM' => '',
+    'VKON' => '',
+    'VVELOX' => '',
+    'JGNI' => '',
+    'MIKKOI' => '',
 );
 
 
@@ -38,28 +43,33 @@ Acme::CPANAuthors::CPAN::Streaks::WeeklyDistributions::Current - Authors with on
 
 =head1 VERSION
 
-This document describes version 20231211.0 of Acme::CPANAuthors::CPAN::Streaks::WeeklyDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2023-12-11.
+This document describes version 20240101.0 of Acme::CPANAuthors::CPAN::Streaks::WeeklyDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-01-01.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2023-12-11, produced by L<cpan-streaks>):
+Current standings (as of 2024-01-01, produced by L<cpan-streaks>):
 
   +-----------+-----+------------+-------------+
   | author    | len | start_date | status      |
   +-----------+-----+------------+-------------+
-  | PERLANCAR | 486 | 2014-08-24 | ongoing     |
-  | SKIM      |   4 | 2023-11-12 | might-break |
-  | KIMOTO    |   2 | 2023-11-26 | might-break |
-  | AAHAZRED  |   1 | 2023-12-03 | might-break |
-  | ABALAMA   |   1 | 2023-12-03 | might-break |
-  | CGPAN     |   1 | 2023-12-03 | might-break |
-  | DJERIUS   |   1 | 2023-12-03 | might-break |
-  | ETHER     |   1 | 2023-12-03 | might-break |
-  | GBROWN    |   1 | 2023-12-03 | might-break |
-  | JJATRIA   |   1 | 2023-12-03 | might-break |
-  | TEODESIAN |   1 | 2023-12-03 | might-break |
+  | PERLANCAR | 489 | 2014-08-24 | ongoing     |
+  | INGY      |   2 | 2023-12-17 | might-break |
+  | KIMOTO    |   2 | 2023-12-17 | might-break |
+  | AJNN      |   1 | 2023-12-24 | might-break |
+  | BOOK      |   1 | 2023-12-24 | might-break |
+  | GENE      |   1 | 2023-12-24 | might-break |
+  | JKSTILL   |   1 | 2023-12-24 | might-break |
+  | JMATES    |   1 | 2023-12-24 | might-break |
+  | JV        |   1 | 2023-12-24 | might-break |
+  | MATHIAS   |   1 | 2023-12-24 | might-break |
+  | MRDVT     |   1 | 2023-12-24 | might-break |
+  | SKIM      |   1 | 2023-12-24 | might-break |
+  | VKON      |   1 | 2023-12-24 | might-break |
+  | VVELOX    |   1 | 2023-12-24 | might-break |
+  | JGNI      |   1 | 2023-12-31 | ongoing     |
+  | MIKKOI    |   1 | 2023-12-31 | ongoing     |
   +-----------+-----+------------+-------------+
 
 =head1 HOMEPAGE
@@ -101,7 +111,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
